from distutils.core import setup

setup(name='Pynopticon',
      version='0.0.0',
      description='Pynopticon',
      author='Rick Wierenga',
      author_email='rick_wierenga@icloud.com',
      url='https://www.github.com/rickwierenga/pynopticon/',
      packages=['pynopticon'],
   )

